/*******************************************************************************
* \file KIT_QSPI.h
* \version 1.10
*
*  This file provides constants and parameter values for the SMIF component.
*
********************************************************************************
* \copyright
* Copyright 2016-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(KIT_QSPI_CY_SMIF_PDL_H)
#define KIT_QSPI_CY_SMIF_PDL_H

#include "cyfitter.h"
#include "cyfitter_sysint.h"
#include "cyfitter_sysint_cfg.h"

#include "smif/cy_smif.h"
#include "smif/cy_smif_memslot.h"

#if defined(__cplusplus)
extern "C" {
#endif


/***************************************
*   Initial Parameter Constants
****************************************/

/* Interrupt cause group */
#define KIT_QSPI_MEMORY_MODE_ALIGMENT_ERORR     (0UL)
#define KIT_QSPI_TX_COMMAND_FIFO_OVERFLOW       (0UL)
#define KIT_QSPI_TX_DATA_FIFO_OVERFLOW          (0UL)
#define KIT_QSPI_RX_DATA_FIFO_UNDERFLOW         (0UL)

/* TX and RX FIFO trigger group */
#define KIT_QSPI_RX_FIFO_TRIGEER_LEVEL          (0UL)
#define KIT_QSPI_TX_FIFO_TRIGEER_LEVEL          (0UL)



/***************************************
*        Function Prototypes
***************************************/
/**
* \addtogroup group_general
* \{
*/

cy_en_smif_status_t KIT_QSPI_Start(cy_stc_smif_block_config_t *blockConfig, uint32_t timeoutMs);

__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_Init(cy_stc_smif_block_config_t *blockConfig);
__STATIC_INLINE void                KIT_QSPI_Mem_DeInit(void);

__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdWriteEnable(uint32_t slotNumber);
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdWriteDisable(uint32_t slotNumber);
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_QuadEnable(uint32_t slotNumber);
__STATIC_INLINE bool                KIT_QSPI_Mem_IsBusy(uint32_t slotNumber);

__STATIC_INLINE bool                KIT_QSPI_BusyCheck(void);
__STATIC_INLINE uint32_t            KIT_QSPI_GetTxfrStatus(void);

__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdReadSts(uint32_t slotNumber, uint8_t *status, uint8_t command);
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdWriteSts(uint32_t slotNumber,  uint8_t command, uint8_t status);

__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdChipErase( uint32_t slotNumber);
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdSectorErase(uint32_t slotNumber, uint8_t const *sectorAddr);

__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdProgram(uint32_t slotNumber,uint8_t const *addr, 
                                                                    uint8_t *writeBuff, 
                                                                    uint32_t size, 
                                                                    cy_smif_event_cb_t CmdCmpltCb);
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdRead(uint32_t slotNumber, uint8_t const *addr, uint8_t *readBuff, 
                                                                    uint32_t size, 
                                                                    cy_smif_event_cb_t CmdCmpltCb);

__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Encrypt(uint32_t address, uint8_t *data, uint32_t size);

__STATIC_INLINE void KIT_QSPI_Enable(void);
__STATIC_INLINE void KIT_QSPI_Disable(void);

__STATIC_INLINE void              KIT_QSPI_SetMode(cy_en_smif_mode_t mode);
__STATIC_INLINE cy_en_smif_mode_t KIT_QSPI_GetMode(void);

__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_CacheInvalidate(cy_en_smif_cache_en_t cacheType);

__STATIC_INLINE void     KIT_QSPI_Interrupt(void);

/***************************************
*  Internal SMIF function declarations
****************************************/
/** \cond INTERNAL */
__STATIC_INLINE void KIT_QSPI_MemSlotConfigsInit(cy_stc_smif_mem_config_t  * const memConfigs[], 
                                                            uint32_t memConfigsSize);
/** \endcond */

/** \} group_general */


/***************************************
*         Internal Constants
***************************************/

/* GPIO configuration group */
#define KIT_QSPI_DATALINES0_1                   (1UL)
#define KIT_QSPI_DATALINES2_3                   (1UL)
#define KIT_QSPI_DATALINES4_5                   (0UL)
#define KIT_QSPI_DATALINES6_7                   (0UL)
#define KIT_QSPI_SS0                            (1UL)
#define KIT_QSPI_SS1                            (0UL)
#define KIT_QSPI_SS2                            (0UL)
#define KIT_QSPI_SS3                            (0UL)

/* Advanced user: Build configuration*/
#define KIT_QSPI_CYMEM_GEN                      (1UL)

/* DMA Trigger Output */
#define KIT_QSPI_RX_FIFO_DMA_TRIGGER            (0UL)
#define KIT_QSPI_TX_FIFO_DMA_TRIGGER            (0UL)

#define KIT_QSPI_MAX_SLOT_NUMBER    ((uint8_t)SMIF_DEVICE_NR)
#define KIT_QSPI_BAD_SLOT_NUMBER    ((uint8_t)(KIT_QSPI_MAX_SLOT_NUMBER + 1U))

#define KIT_QSPI_HW                 KIT_QSPI_SMIF__HW

#define KIT_QSPI_MEMORIES_NUM       (KIT_QSPI_SS0 + KIT_QSPI_SS1 + \
                                             KIT_QSPI_SS2 + KIT_QSPI_SS3)

#define KIT_QSPI_TX_FIFO_TRIGGER    (0UL)
#define KIT_QSPI_RX_FIFO_TRIGGER    (0UL)


/***************************************
* Kept for backward compatibility
***************************************/

#define KIT_QSPI_EN_DMA_READ        KIT_QSPI_RX_FIFO_DMA_TRIGGER
#define KIT_QSPI_EN_DMA_WRITE       KIT_QSPI_TX_FIFO_DMA_TRIGGER

/**
* \addtogroup group_globals
* \{
*/
/** Allocate space for context. */
extern cy_stc_smif_context_t KIT_QSPI_context;

/** Allocate space memory configurations. */
extern cy_stc_smif_mem_config_t* KIT_QSPI_memSlotConfigs[KIT_QSPI_MAX_SLOT_NUMBER];

/** Allocate space device configuration. */
extern cy_stc_smif_config_t const KIT_QSPI_config;

extern uint8_t KIT_QSPI_initVar;

/** \} group_globals */


/**
* \addtogroup group_constants
* \{
*/
#define KIT_QSPI_DESELECT_DELAY          (7u)            /**< Minimum duration of SPI de-selection */ 

/** 
 *  What happens when there is a Read to an empty RX FIFO or a Write to a full TX 
 *  FIFO.
 */ 
#define KIT_QSPI_AHB_BUS_ERROR           (0u)            

/** \} group_constants */


#define KIT_QSPI_SMIF_INTR_MASK   ( _VAL2FLD(SMIF_INTR_TR_TX_REQ, KIT_QSPI_TX_FIFO_TRIGGER)                      |\
                                            _VAL2FLD(SMIF_INTR_TR_RX_REQ, KIT_QSPI_RX_FIFO_TRIGGER)                      |\
                                            _VAL2FLD(SMIF_INTR_XIP_ALIGNMENT_ERROR, KIT_QSPI_MEMORY_MODE_ALIGMENT_ERORR) |\
                                            _VAL2FLD(SMIF_INTR_TX_CMD_FIFO_OVERFLOW, KIT_QSPI_TX_COMMAND_FIFO_OVERFLOW)  |\
                                            _VAL2FLD(SMIF_INTR_TX_DATA_FIFO_OVERFLOW, KIT_QSPI_TX_DATA_FIFO_OVERFLOW)    |\
                                            _VAL2FLD(SMIF_INTR_RX_DATA_FIFO_UNDERFLOW, KIT_QSPI_RX_DATA_FIFO_UNDERFLOW))     


/***************************************
*    In-line Function Implementation
***************************************/

/*******************************************************************************
* Function Name: KIT_QSPI_Mem_Init
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_Init() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_Init(cy_stc_smif_block_config_t *blockConfig)
{
    KIT_QSPI_MemSlotConfigsInit(blockConfig->memConfig, blockConfig->memCount);
    return Cy_SMIF_Memslot_Init(KIT_QSPI_HW , blockConfig, &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_DeInit
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_DeInit() PDL driver function.
* 
*******************************************************************************/
__STATIC_INLINE void KIT_QSPI_Mem_DeInit(void)
{
    Cy_SMIF_Memslot_DeInit(KIT_QSPI_HW );
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_CmdWriteEnable
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_CmdWriteEnable() PDL driver function.
*
* \param slotNumber
* The slave device ID. This number is either 0, 1, 2, or 3. This is decided by the 
* slave select line to be used while a transmit is happening.
* 
* \note For details, see the description of the Cy_SMIF_Memslot_CmdWriteEnable()  
* PDL driver function in the PDL API Reference Guide.
* 
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdWriteEnable(uint32_t slotNumber)
{
    return Cy_SMIF_Memslot_CmdWriteEnable(KIT_QSPI_HW, 
                KIT_QSPI_memSlotConfigs[slotNumber], &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_CmdWriteDisable
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_CmdWriteDisable() PDL driver function.
*
* \param slotNumber
* The slave device ID. This number is either 0, 1, 2, or 3. This is decided by the 
* slave select line to be used while a transmit is happening.
* 
* \note For details, see the description of the Cy_SMIF_Memslot_CmdWriteDisable()  
* PDL driver function in the PDL API Reference Guide.
* 
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdWriteDisable(uint32_t slotNumber)
{
    return Cy_SMIF_Memslot_CmdWriteDisable(KIT_QSPI_HW, 
                KIT_QSPI_memSlotConfigs[slotNumber], &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_IsBusy
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_IsBusy() PDL driver function.
*
* \param slotNumber
* The slave device ID. This number is either 0, 1, 2, or 3. This is decided by the 
* slave select line to be used while a transmit is happening.
* 
* \note For details, see the description of the Cy_SMIF_Memslot_IsBusy()  
* PDL driver function in PDL API Reference Guide.
* 
*******************************************************************************/
__STATIC_INLINE bool KIT_QSPI_Mem_IsBusy(uint32_t slotNumber)
{
    return Cy_SMIF_Memslot_IsBusy( KIT_QSPI_HW, 
            KIT_QSPI_memSlotConfigs[slotNumber], &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_QuadEnable
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_QuadEnable() PDL driver function.
*
* \param slotNumber
* The slave device ID. This number is either 0, 1, 2, or 3. This is decided by the 
* slave select line to be used while a transmit is happening.
* 
* \note For details, see the description of the Cy_SMIF_Memslot_QuadEnable()  
* PDL driver function in the PDL API Reference Guide.
* 
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_QuadEnable(uint32_t slotNumber)
{
    return Cy_SMIF_Memslot_QuadEnable(KIT_QSPI_HW, 
            KIT_QSPI_memSlotConfigs[slotNumber], &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_CmdReadSts
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_CmdReadSts() PDL driver function.
*
* \param slotNumber
* The slave device ID. This number is either 0, 1, 2, or 3. This is decided by the 
* slave select line to be used while a transmit is happening.
* 
* \note For details, see the description of the Cy_SMIF_Memslot_CmdReadSts()  
* PDL driver function in the PDL API Reference Guide.
* 
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdReadSts(uint32_t slotNumber,
                                                            uint8_t *status, 
                                                            uint8_t command)
{
    return Cy_SMIF_Memslot_CmdReadSts(KIT_QSPI_HW, 
            KIT_QSPI_memSlotConfigs[slotNumber], status, command, 
            &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_CmdWriteSts
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_CmdWriteSts() PDL driver function.
*
* \param slotNumber
* The slave device ID. This number is either 0, 1, 2, or 3. This is decided by the 
* slave select line to be used while a transmit is happening.
*  
* \note For details, see the description of the Cy_SMIF_Memslot_CmdWriteSts()  
* PDL driver function in the PDL API Reference Guide.
* 
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdWriteSts(uint32_t slotNumber,
                                                            uint8_t command, 
                                                            uint8_t status)
{
    return Cy_SMIF_Memslot_CmdWriteSts(KIT_QSPI_HW,                                     
                                    KIT_QSPI_memSlotConfigs[slotNumber], 
                                    &status,
                                    command,
                                    &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_CmdChipErase
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_CmdChipErase() PDL driver function.
*
* \param slotNumber
* The slave device ID. This number is either 0, 1, 2, or 3. This is decided by the 
* slave select line to be used while a transmit is happening.
* 
* \note For details, see the description of the Cy_SMIF_Memslot_CmdChipErase()  
* PDL driver function in the PDL API Reference Guide.
* 
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdChipErase(uint32_t slotNumber)
{
    return Cy_SMIF_Memslot_CmdChipErase(KIT_QSPI_HW ,
                                   KIT_QSPI_memSlotConfigs[slotNumber],
                                    &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_CmdSectorErase
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_CmdSectorErase() PDL driver function.
*
* \param slotNumber
* The slave device ID. This number is either 0, 1, 2, or 3. This is decided by the 
* slave select line to be used while a transmit is happening.
* 
* \note For details, see the description of the Cy_SMIF_Memslot_CmdSectorErase()  
* PDL driver function in the PDL API Reference Guide.
* 
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdSectorErase(uint32_t slotNumber, 
                                                    uint8_t const *sectorAddr)
{
    return Cy_SMIF_Memslot_CmdSectorErase(KIT_QSPI_HW ,
                                        KIT_QSPI_memSlotConfigs[slotNumber], 
                                        sectorAddr,
                                        &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_CmdProgram
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_CmdProgram() PDL driver function.
*
* \param slotNumber
* The slave device ID. This number is either 0, 1, 2, or 3. This is decided by the 
* slave select line to be used while a transmit is happening.
* 
* \note For details, see the description of the Cy_SMIF_Memslot_CmdProgram() PDL 
* driver function in the PDL API Reference Guide.
* 
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdProgram(uint32_t slotNumber, 
                                                            uint8_t const *addr, 
                                                            uint8_t *writeBuff, 
                                                            uint32_t size, 
                                                            cy_smif_event_cb_t CmdCmpltCb)
{
    return Cy_SMIF_Memslot_CmdProgram(KIT_QSPI_HW,                                    
                                    KIT_QSPI_memSlotConfigs[slotNumber], 
                                    addr, 
                                    writeBuff, 
                                    size,
                                    CmdCmpltCb,
                                    &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Mem_CmdRead
****************************************************************************//**
*
* Invokes the Cy_SMIF_Memslot_CmdRead() PDL driver function.
*
* \param slotNumber
* The slave device ID. This number is either 0, 1, 2, or 3. This is decided by the slave
* select line to be used while a transmit is happening.
* 
* \note For details, see the description of the Cy_SMIF_Memslot_CmdRead() PDL 
* driver function in the PDL API Reference Guide.
* 
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Mem_CmdRead(uint32_t slotNumber, 
                                                            uint8_t const *addr, 
                                                            uint8_t *readBuff, 
                                                            uint32_t size, 
                                                            cy_smif_event_cb_t CmdCmpltCb)
{
    return Cy_SMIF_Memslot_CmdRead(KIT_QSPI_HW,                                    
                                    KIT_QSPI_memSlotConfigs[slotNumber], 
                                    addr, 
                                    readBuff, 
                                    size,
                                    CmdCmpltCb,
                                    &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Interrupt
****************************************************************************//**
*
* Invokes the Cy_SMIF_Interrupt() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void KIT_QSPI_Interrupt(void)
{
    Cy_SMIF_Interrupt(KIT_QSPI_HW , &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Encrypt
****************************************************************************//**
*
* Invokes the Cy_SMIF_Encrypt() PDL driver function.
* 
* \note For details, see the cryptography subsection in the Serial Memory Interface 
* (SMIF) section in the chip technical reference manual (TRM). 
*
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_Encrypt(uint32_t address,
                                                    uint8_t *data,
                                                    uint32_t size)
{
    return Cy_SMIF_Encrypt(KIT_QSPI_HW, address, data, size,
                            &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Enable
****************************************************************************//**
*
* Invokes the Cy_SMIF_Enable() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void KIT_QSPI_Enable(void)
{
    Cy_SMIF_Enable(KIT_QSPI_HW, &KIT_QSPI_context);
}


/*******************************************************************************
* Function Name: KIT_QSPI_Disable
****************************************************************************//**
*
* Invokes the Cy_SMIF_Disable() PDL driver function. 
*
*******************************************************************************/
__STATIC_INLINE void KIT_QSPI_Disable(void)
{
    Cy_SMIF_Disable(KIT_QSPI_HW);
}


/*******************************************************************************
* Function Name: KIT_QSPI_SetMode
****************************************************************************//**
*
* Invokes the Cy_SMIF_SetMode() PDL driver function. 
*
*******************************************************************************/
__STATIC_INLINE void     KIT_QSPI_SetMode(cy_en_smif_mode_t mode)
{
    Cy_SMIF_SetMode(KIT_QSPI_HW , mode);
}


/*******************************************************************************
* Function Name: KIT_QSPI_GetMode
****************************************************************************//**
*
* Invokes the SMIF_GetMode() PDL driver function. 
*
*******************************************************************************/
__STATIC_INLINE cy_en_smif_mode_t KIT_QSPI_GetMode(void)
{
    return Cy_SMIF_GetMode(KIT_QSPI_HW );
}


/*******************************************************************************
* Function Name: KIT_QSPI_BusyCheck
****************************************************************************//**
*
* Invokes the SMIF_BusyCheck() PDL driver function. 
*
*******************************************************************************/
__STATIC_INLINE bool KIT_QSPI_BusyCheck(void)
{
    return Cy_SMIF_BusyCheck(KIT_QSPI_HW );
}


/*******************************************************************************
* Function Name: KIT_QSPI_CacheInvalidate
****************************************************************************//**
*
* Invokes the SMIF_CacheInvalidate() PDL driver function. 
*
*******************************************************************************/
__STATIC_INLINE cy_en_smif_status_t KIT_QSPI_CacheInvalidate(cy_en_smif_cache_en_t cacheType)
{
    return Cy_SMIF_CacheInvalidate(KIT_QSPI_HW , cacheType);
}


/*******************************************************************************
* Function Name: KIT_QSPI_GetTxfrStatus
****************************************************************************//**
*
* Invokes the SMIF_GetTxfrStatus() PDL driver function. 
*
*******************************************************************************/
__STATIC_INLINE uint32_t KIT_QSPI_GetTxfrStatus(void)
{
    return Cy_SMIF_GetTxfrStatus(KIT_QSPI_HW , &KIT_QSPI_context);
}


/***************************************
*  Internal SMIF inline functions 
****************************************/

/** \cond INTERNAL */

/*******************************************************************************
* Function Name: KIT_QSPI_MemSlotConfigsInit
****************************************************************************//**
*
*  \internal
*  This function initializes the KIT_QSPI_memSlotConfigs arrays with 
*  the pointers to the device memory configuration structure. The index of the 
*  KIT_QSPI_memSlotConfigs array is equal to the device slotNumber number.     
*   
* \param memConfigs
* The configuration structure array that configures the SMIF memory device to be  
* mapped into the PSoC memory map. \ref cy_stc_smif_mem_config_t 
*
* \globalvars
*  KIT_QSPI_memSlotConfigs The component array of the external memory 
*  configuration structures.
*
*******************************************************************************/
__STATIC_INLINE void KIT_QSPI_MemSlotConfigsInit(cy_stc_smif_mem_config_t  * const memConfigs[], 
                                                            uint32_t memConfigsSize)
{
    uint8_t slotIndex;

    /* Initialization of _memSlotConfigs*/
    for(slotIndex = 0U; slotIndex < KIT_QSPI_MAX_SLOT_NUMBER; slotIndex++)
    {
        KIT_QSPI_memSlotConfigs[slotIndex] = NULL;
    }

    /* Filling of _memSlotConfigs */
    if (NULL != memConfigs)
    {
        uint8_t slotNumber = KIT_QSPI_BAD_SLOT_NUMBER;
        for(slotIndex = 0U; slotIndex < memConfigsSize; slotIndex++)
        {
            if (NULL != memConfigs[slotIndex])
            {       
                switch ((cy_en_smif_slave_select_t)memConfigs[slotIndex]->slaveSelect)
                {
                    case CY_SMIF_SLAVE_SELECT_0:
                        slotNumber = 0U;            
                        break;
                    case CY_SMIF_SLAVE_SELECT_1:
                        slotNumber = 1U;         
                        break;
                    case CY_SMIF_SLAVE_SELECT_2:
                        slotNumber = 2U;           
                        break;
                    case CY_SMIF_SLAVE_SELECT_3:
                        slotNumber = 3U;         
                        break;
                    default:
                        /* User error: the slot number is not supported*/
                        slotNumber = KIT_QSPI_BAD_SLOT_NUMBER;
                        break;
                }
                if (slotNumber < KIT_QSPI_MAX_SLOT_NUMBER)
                {
                    KIT_QSPI_memSlotConfigs[slotNumber] = memConfigs[slotIndex];
                }
            }  
        }
    }
}

/** \endcond */


#if defined(__cplusplus)
}
#endif

#endif /* KIT_QSPI_CY_SMIF_PDL_H */


/* [] END OF FILE */
